==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebScrollStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebScrollStrategyDescription } from "./WebScrollStrategyDescription";
/**
 * @hidden
 */
var WebScrollStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebScrollStrategyDescriptionMetadata, _super);
    function WebScrollStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebScrollStrategyDescriptionMetadata.b = function (a) {
        if (WebScrollStrategyDescriptionMetadata.a == null) {
            WebScrollStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebScrollStrategyDescriptionMetadata.c(WebScrollStrategyDescriptionMetadata.a);
        }
        if (a.j(WebScrollStrategyDescriptionMetadata.a)) {
            return;
        }
        a.y(WebScrollStrategyDescriptionMetadata.a);
    };
    WebScrollStrategyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ScrollStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
    };
    WebScrollStrategyDescriptionMetadata.d = function (a) {
        WebScrollStrategyDescriptionMetadata.b(a);
        a.aa("WebScrollStrategy", function () { return new WebScrollStrategyDescription(); });
        a.z("WebScrollStrategy", WebScrollStrategyDescriptionMetadata.a);
    };
    WebScrollStrategyDescriptionMetadata.$t = markType(WebScrollStrategyDescriptionMetadata, 'WebScrollStrategyDescriptionMetadata');
    WebScrollStrategyDescriptionMetadata.a = null;
    return WebScrollStrategyDescriptionMetadata;
}(Base));
export { WebScrollStrategyDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebScrollStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebScrollStrategyDescription } from "./WebScrollStrategyDescription";
/**
 * @hidden
 */
var WebScrollStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebScrollStrategyDescriptionMetadata, _super);
    function WebScrollStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebScrollStrategyDescriptionMetadata.b = function (a) {
        if (WebScrollStrategyDescriptionMetadata.a == null) {
            WebScrollStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebScrollStrategyDescriptionMetadata.c(WebScrollStrategyDescriptionMetadata.a);
        }
        if (a.k(WebScrollStrategyDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebScrollStrategyDescriptionMetadata.a);
    };
    WebScrollStrategyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ScrollStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebScrollStrategyDescriptionMetadata.d = function (a) {
        WebScrollStrategyDescriptionMetadata.b(a);
        a.ac("WebScrollStrategy", function () { return new WebScrollStrategyDescription(); });
        a.ab("WebScrollStrategy", WebScrollStrategyDescriptionMetadata.a);
    };
    WebScrollStrategyDescriptionMetadata.$t = markType(WebScrollStrategyDescriptionMetadata, 'WebScrollStrategyDescriptionMetadata');
    WebScrollStrategyDescriptionMetadata.a = null;
    return WebScrollStrategyDescriptionMetadata;
}(Base));
export { WebScrollStrategyDescriptionMetadata };
